@@ -35,6 +35,7 @@
 enum {
     PROP_0,
     PROP_KEY_TYPE,
+    PROP_KEY_DESC,
     PROP_LOCATION,
     PROP_KEY_SERVER,
     PROP_URI
@@ -63,10 +64,7 @@ static void seahorse_server_set_property      (GObject *object, guint prop_id,
 /* SeahorseKeySource methods */
 static void         seahorse_server_source_stop        (SeahorseKeySource *src);
 static guint        seahorse_server_source_get_state   (SeahorseKeySource *src);
-static SeahorseOperation*  seahorse_server_source_load (SeahorseKeySource *src,
-                                                        SeahorseKeySourceLoad load,
-                                                        GQuark keyid,
-                                                        const gchar *match);
+static SeahorseOperation*  seahorse_server_source_load (SeahorseKeySource *src, GQuark keyid);
 
 static GObjectClass *parent_class = NULL;
 
@@ -95,6 +93,10 @@ seahorse_server_source_class_init (SeahorseServerSourceClass *klass)
         g_param_spec_uint ("key-type", "Key Type", "Key type that originates from this key source.", 
                            0, G_MAXUINT, SKEY_UNKNOWN, G_PARAM_READABLE));
 
+    g_object_class_install_property (gobject_class, PROP_KEY_DESC,
+        g_param_spec_string ("key-desc", "Key Desc", "Description for keys that originate here.",
+                             NULL, G_PARAM_READABLE));
+
     g_object_class_install_property (gobject_class, PROP_LOCATION,
         g_param_spec_uint ("location", "Key Location", "Where the key is stored. See SeahorseKeyLoc", 
                            0, G_MAXUINT, SKEY_LOC_INVALID, G_PARAM_READABLE));    
@@ -204,6 +206,9 @@ seahorse_server_get_property (GObject *object, guint prop_id, GValue *value,
     case PROP_KEY_TYPE:
         g_value_set_uint (value, SKEY_PGP);
         break;
+    case PROP_KEY_DESC:
+        g_value_set_string (value, _("PGP Key"));
+        break;
     case PROP_LOCATION:
         g_value_set_uint (value, SKEY_LOC_REMOTE);
         break;
@@ -306,8 +311,7 @@ seahorse_server_source_take_operation (SeahorseServerSource *ssrc, SeahorseOpera
  */
 
 static SeahorseOperation*
-seahorse_server_source_load (SeahorseKeySource *src, SeahorseKeySourceLoad load,
-                             GQuark keyid, const gchar *match)
+seahorse_server_source_load (SeahorseKeySource *src, GQuark keyid)
 {
     SeahorseServerSource *ssrc;
     GList *keys, *l;
@@ -315,17 +319,6 @@ seahorse_server_source_load (SeahorseKeySource *src, SeahorseKeySourceLoad load,
     g_assert (SEAHORSE_IS_KEY_SOURCE (src));
     ssrc = SEAHORSE_SERVER_SOURCE (src);
 
-    if (load == SKSRC_LOAD_ALL) {
-        /* Stop all operations */
-        seahorse_server_source_stop (src);
-
-        /* Remove all keys */
-        keys = seahorse_context_get_keys (SCTX_APP (), src);
-        for (l = keys; l; l = g_list_next (l))
-            seahorse_context_remove_key (SCTX_APP(), SEAHORSE_KEY (l->data));
-        g_list_free (keys);
-    }
-    
     /* We should never be called directly */
     return NULL;
 }
@@ -447,7 +440,7 @@ seahorse_server_source_new (const gchar *server)
         } else
 #endif /* WITH_HKP */
         
-            g_warning ("unsupported keyserver uri scheme: %s", scheme);
+            g_warning ("unsupported key server uri scheme: %s", scheme);
     }
     
     g_free (uri);
@@ -483,6 +476,9 @@ seahorse_server_source_get_descriptions()
 gboolean
 seahorse_server_source_valid_uri (const gchar *uri)
 {
+    if (!uri || !*uri)
+        return FALSE;
+    
 #ifdef WITH_LDAP
     if (seahorse_ldap_is_valid_uri (uri))
         return TRUE;
