@@ -681,7 +681,7 @@ backup_activate (GtkWidget *widget, SeahorseWidget *swidget)
     gchar *ext, *t;
     const gchar* home_dir = NULL;
     
-    dialog = seahorse_util_chooser_save_new (_("Back up Keyrings to Archive"), 
+    dialog = seahorse_util_chooser_save_new (_("Back up Key Rings to Archive"), 
                 GTK_WINDOW(glade_xml_get_widget (swidget->xml, "key-manager")));
     seahorse_util_chooser_show_archive_files (dialog);	    	    	    
 
@@ -1072,7 +1072,7 @@ tab_changed (GtkWidget *widget, GtkNotebookPage *page, guint page_num,
     
     /* 
      * Because gnome-keyring can throw prompts etc... we delay loading 
-     * of the gnome keyring items until we first access them. 
+     * of the gnome key ring items until we first access them. 
      */
     
 #ifdef WITH_GNOME_KEYRING
@@ -1177,8 +1177,8 @@ static const GtkActionEntry ui_entries[] = {
     { "key-generate", GTK_STOCK_NEW, N_("_Create New Key..."), "<control>N", 
             N_("Create a new personal key"), G_CALLBACK (generate_activate) },
     { "key-import-file", GTK_STOCK_OPEN, N_("_Import..."), "<control>I",
-            N_("Import keys into your keyring from a file"), G_CALLBACK (import_activate) },
-    { "key-backup", GTK_STOCK_SAVE, N_("_Back up Keyrings..."), "",
+            N_("Import keys into your key ring from a file"), G_CALLBACK (import_activate) },
+    { "key-backup", GTK_STOCK_SAVE, N_("_Back up Key Rings..."), "",
             N_("Back up all keys"), G_CALLBACK (backup_activate) }, 
     { "key-import-clipboard", GTK_STOCK_PASTE, N_("Paste _Keys"), "<control>V",
             N_("Import keys from the clipboard"), G_CALLBACK (paste_activate) }, 
@@ -1197,14 +1197,14 @@ static const GtkActionEntry ui_entries[] = {
 };
 
 static const GtkToggleActionEntry view_entries[] = {
-    { "view-type", NULL, N_("Key T_ypes"), NULL,
-             N_("Show key type column"), G_CALLBACK (view_type_column), FALSE },
-    { "view-expires", NULL, N_("Key _Expiry"), NULL,
-             N_("Show key expiry column"), G_CALLBACK (view_expiry_column), FALSE },
-    { "view-trust", NULL, N_("Key _Trust"), NULL,
+    { "view-type", NULL, N_("T_ypes"), NULL,
+             N_("Show type column"), G_CALLBACK (view_type_column), FALSE },
+    { "view-expires", NULL, N_("_Expiry"), NULL,
+             N_("Show expiry column"), G_CALLBACK (view_expiry_column), FALSE },
+    { "view-trust", NULL, N_("_Trust"), NULL,
              N_("Show owner trust column"), G_CALLBACK (view_trust_column), FALSE },
-    { "view-validity", NULL, N_("Key _Validity"), NULL,
-             N_("Show key validity column"), G_CALLBACK (view_validity_column), FALSE },
+    { "view-validity", NULL, N_("_Validity"), NULL,
+             N_("Show validity column"), G_CALLBACK (view_validity_column), FALSE },
 };
 
 static const GtkActionEntry key_entries[] = {
@@ -1232,7 +1232,7 @@ static const GtkActionEntry keyserver_entries[] = {
     { "remote-find", GTK_STOCK_FIND, N_("_Find Remote Keys..."), "",
             N_("Search for keys on a key server"), G_CALLBACK (search_activate) }, 
     { "remote-sync", GTK_STOCK_REFRESH, N_("_Sync and Publish Keys..."), "",
-            N_("Publish and/or sync your keys with those online."), G_CALLBACK (sync_activate) }, 
+            N_("Publish and/or synchronize your keys with those online."), G_CALLBACK (sync_activate) }, 
 };
 
 void
