@@ -144,8 +144,8 @@ seahorse_keyserver_sync_show (GList *keys)
     
     /* The details message */
     n = g_list_length (keys);
-    t = g_strdup_printf (ngettext ("<b>%d key is selected for syncing</b>", 
-                                   "<b>%d keys are selected for syncing</b>", n), n);
+    t = g_strdup_printf (ngettext ("<b>%d key is selected for synchronizing</b>", 
+                                   "<b>%d keys are selected for synchronizing</b>", n), n);
     
     w = glade_xml_get_widget (swidget->xml, "detail-message");
     g_return_val_if_fail (swidget != NULL, win);
@@ -195,7 +195,7 @@ seahorse_keyserver_sync (GList *keys)
 
     mop = seahorse_multi_operation_new ();
 
-    /* And now syncing keys from the servers */
+    /* And now synchronizing keys from the servers */
     ks = seahorse_gconf_get_string_list (KEYSERVER_KEY);
     ks = seahorse_server_source_purge_keyservers (ks);
     
@@ -211,7 +211,7 @@ seahorse_keyserver_sync (GList *keys)
                         seahorse_key_source_get_ktype (sksrc), SKEY_LOC_LOCAL);
         
         if (lsksrc) {
-            op = seahorse_transfer_operation_new (_("Syncing keys"), sksrc, lsksrc, keyids);
+            op = seahorse_transfer_operation_new (_("Synchronizing keys"), sksrc, lsksrc, keyids);
             g_return_if_fail (op != NULL);
 
             seahorse_multi_operation_take (mop, op);
@@ -243,6 +243,6 @@ seahorse_keyserver_sync (GList *keys)
     g_free (keyserver);
     
     /* Show the progress window if necessary */
-    seahorse_progress_show (SEAHORSE_OPERATION (mop), _("Syncing keys..."), FALSE);
+    seahorse_progress_show (SEAHORSE_OPERATION (mop), _("Synchronizing keys..."), FALSE);
     g_object_unref (mop);
 }
