@@ -39,7 +39,7 @@ upload_complete (SeahorseOperation *op, gpointer dummy)
     
     if (!seahorse_operation_is_successful (op)) {
         seahorse_operation_copy_error (op, &err);
-        seahorse_util_handle_error (err, _("Couldn't configure SSH keys on remote computer."));
+        seahorse_util_handle_error (err, _("Couldn't configure Secure Shell keys on remote computer."));
     }    
 }
 
@@ -115,7 +115,7 @@ upload_keys (SeahorseWidget *swidget)
 {
     SeahorseOperation *op;
     GtkWidget *widget;
-    const gchar *user, *host, *port;
+    const gchar *user, *host;
     GList *keys;
     gchar *t;
 
@@ -127,17 +127,9 @@ upload_keys (SeahorseWidget *swidget)
     host = gtk_entry_get_text (GTK_ENTRY (widget));
     g_return_if_fail (host && host[0]);
 
-    widget = glade_xml_get_widget (swidget->xml, "port-label");
-    port = gtk_entry_get_text (GTK_ENTRY (widget));
-
     keys = (GList*)g_object_steal_data (G_OBJECT (swidget), "upload-keys");
     g_return_if_fail (keys != NULL);
     
-    if (port && port[0])
-        t = g_strdup_printf ("%s:%s", host, port);
-    else
-        t = g_strdup (host);
-    
     /* This frees |keys| */
     op = upload_via_source (user, host, keys);
     g_return_if_fail (op != NULL);
@@ -145,7 +137,7 @@ upload_keys (SeahorseWidget *swidget)
     seahorse_operation_watch (op, G_CALLBACK (upload_complete), NULL, NULL);
     
     /* Show the progress window if necessary */
-    seahorse_progress_show (op, _("Configuring SSH Keys..."), FALSE);
+    seahorse_progress_show (op, _("Configuring Secure Shell Keys..."), FALSE);
     g_object_unref (op);
 }
 
@@ -169,11 +161,6 @@ seahorse_ssh_upload_prompt (GList *keys)
     
     win = GTK_WINDOW (glade_xml_get_widget (swidget->xml, swidget->name));
 
-    /* Set the image properly */
-    w = glade_xml_get_widget (swidget->xml, "icon-image");
-    gtk_image_set_from_stock (GTK_IMAGE (w), SEAHORSE_STOCK_KEY_SSH, 
-                              GTK_ICON_SIZE_DIALOG);
-
     /* Default to the users current name */
     w = glade_xml_get_widget (swidget->xml, "user-label");
     gtk_entry_set_text (GTK_ENTRY (w), g_get_user_name ());
